@@ -474,6 +474,15 @@ class Factura(object):
                 data.append(ConceptoRepercutible(d))
         return data
 
+    def get_tipus_punt_mesura(self):
+        try:
+            if self.factura.DatosGeneralesFacturaATR and self.factura.DatosGeneralesFacturaATR.DatosFacturaATR:
+                if self.factura.DatosGeneralesFacturaATR.DatosFacturaATR.TipoPM:
+                    return self.factura.DatosGeneralesFacturaATR.DatosFacturaATR.TipoPM.text
+        except AttributeError:
+            # We might not have any "TipoPM" in DatosFacturaATR
+            pass
+
     def get_coeficient_repartiment(self):
         try:
             if self.factura.Autoconsumo and self.factura.Autoconsumo.InstalacionGenAutoconsumo:
@@ -482,7 +491,7 @@ class Factura(object):
                     if instalacio.EnergiaNetaGen:
                         for terme in instalacio.EnergiaNetaGen.TerminoEnergiaNetaGen:
                             for periode in terme.Periodo:
-                                if periode.valor_energia_neta_gen:
+                                if periode.ValorEnergiaNetaGen:
                                     beta_list.append(float(periode.Beta.text))
                 return list(set(beta_list))
         except AttributeError:
@@ -650,7 +659,7 @@ class PeriodoPotencia(Periodo):
     @property
     def recargo_inf_anio(self):
         if hasattr(self.periodo, 'RecargoInfAnio'):
-            return int(self.periodo.RecargoInfAnio.text.strip())
+            return int(float(self.periodo.RecargoInfAnio.text.strip()))
         return None
 
 
@@ -1518,6 +1527,8 @@ class ModeloAparato(object):
         data = []
         if hasattr(self.modelo_aparato, 'Integrador'):
             integradors_dh_per_data = {}
+            totalitzadors_per_data = {}
+            integradors_per_data_i_periode = {}
             for d in self.modelo_aparato.Integrador:
                 integrador = Integrador(d)
                 if integrador.codigo_periodo in ['21', '22', '81', '82', '83'] and integrador.magnitud == 'PM':
@@ -1526,9 +1537,22 @@ class ModeloAparato(object):
                     # Els guardem per tractarlos despres
                     integradors_dh_per_data.setdefault(integrador.lectura_hasta.fecha, [])
                     integradors_dh_per_data[integrador.lectura_hasta.fecha].append(integrador)
+                elif integrador.codigo_periodo in ['90', 'A0']:
+                    totalitzadors_per_data.setdefault(integrador.lectura_hasta.fecha, [])
+                    totalitzadors_per_data[integrador.lectura_hasta.fecha].append(integrador)
                 else:
+                    integradors_per_data_i_periode.setdefault(integrador.lectura_hasta.fecha, {})
+                    integradors_per_data_i_periode[integrador.lectura_hasta.fecha].setdefault(integrador.periode, [])
+                    integradors_per_data_i_periode[integrador.lectura_hasta.fecha][integrador.periode].append(integrador)
                     data.append(integrador)
 
+            for data_totalitzador, totalitzadors in totalitzadors_per_data.items():
+                for totalitzador in totalitzadors_per_data[data_totalitzador]:
+                    if data_totalitzador not in integradors_per_data_i_periode:
+                        data.append(totalitzador)
+                    elif totalitzador.periode not in integradors_per_data_i_periode[data_totalitzador]:
+                        data.append(totalitzador)
+
             # Per tractar els multiples periodes en una DH nosaltres agafarem
             # la lectura mes gran de cada data com a P1 ja que no hi ha altres
             # Px de potencia per una DHx.
@@ -1811,6 +1835,8 @@ class FacturaATR(Factura):
             return False
         if self.datos_factura.tipo_factura in ('G', 'C'):
             return False
+        if self.datos_factura.vas_trafo or self.datos_factura.porcentaje_perdidas:
+            return False
         for c in self.get_comptadors():
             for l in c.get_lectures(force_no_transforma_no_td_a_td=True):
                 if isinstance(l.consumo_calculado, int):
